==> shinyStorePlus_1.4.zip: shinyStorePlus/NEWS.md <==
# shinyStorePlus 1.4
--------------------------------------------------------------------------
##  Features

- [x] shiny observe event execution ONCE across multiple browser sessions. This can be useful to display a welcome message to users only the first time they visit your app. Or a cookie acceptance panel shown once. The point is that, when the user refreshed the app or returns to the app later, the execution will no longer occur since it had been shown to the user previously.

# shinyStorePlus 1.3
--------------------------------------------------------------------------
## Features

- [x] Store app views across all visitors
- [x] Store app likes from visitors
- [x] Store app followers

# shinyStorePlus 1.2
--------------------------------------------------------------------------
## Features

- [x] Store dynamically generated inputs, like inputs created from the server function of the shiny app. See examples in the GitHub project link

# shinyStorePlus 1.1
--------------------------------------------------------------------------
## Features

- [x] Compatibility for shinyWidgets package

# shinyStorePlus 0.9
--------------------------------------------------------------------------
## Features

- [x] Store some outputs automatically 
- [x] Updated examples of the package in action, see https://github.com/oobianom/aagarw30_shinyapps_to-shinyStorePlus

# shinyStorePlus 0.8
--------------------------------------------------------------------------
## Features

- [x] Convert browser link parameters into Shiny input values e.g Transfer the value of 'name' in http://link.com/?name=obianom to a Shiny input

# shinyStorePlus 0.7
--------------------------------------------------------------------------
## Features

- [x] Bug fix on clearStore

# shinyStorePlus 0.6
----------------------------------------------------------------------------
## Features

- [x] Store inputs automatically 
- [x] Retrieve all stored inputs
- [x] Clear Storage of all inputs
- [x] An example of the package in action

==> shinyStorePlus_1.6.zip: shinyStorePlus/NEWS.md <==
# shinyStorePlus 1.6
--------------------------------------------------------------------------
##  Features

- [x] Extend the functionality of "*" for dynamic inputs in order to allow detection of subtree additions

# shinyStorePlus 1.5
--------------------------------------------------------------------------
##  Features

- [x] Update to setupStorage(), allowing the use of "*" to select dynamic IDs starting or ending with particular words. Example at /inst/example/dynamicInput/app2.R

# shinyStorePlus 1.4
--------------------------------------------------------------------------
##  Features

- [x] shiny observe event execution ONCE across multiple browser sessions. This can be useful to display a welcome message to users only the first time they visit your app. Or a cookie acceptance panel shown once. The point is that, when the user refreshed the app or returns to the app later, the execution will no longer occur since it had been shown to the user previously.

# shinyStorePlus 1.3
--------------------------------------------------------------------------
## Features

- [x] Store app views across all visitors
- [x] Store app likes from visitors
- [x] Store app followers

# shinyStorePlus 1.2
--------------------------------------------------------------------------
## Features

- [x] Store dynamically generated inputs, like inputs created from the server function of the shiny app. See examples in the GitHub project link

# shinyStorePlus 1.1
--------------------------------------------------------------------------
## Features

- [x] Compatibility for shinyWidgets package

# shinyStorePlus 0.9
--------------------------------------------------------------------------
## Features

- [x] Store some outputs automatically 
- [x] Updated examples of the package in action, see https://github.com/oobianom/aagarw30_shinyapps_to-shinyStorePlus

# shinyStorePlus 0.8
--------------------------------------------------------------------------
## Features

- [x] Convert browser link parameters into Shiny input values e.g Transfer the value of 'name' in http://link.com/?name=obianom to a Shiny input

# shinyStorePlus 0.7
--------------------------------------------------------------------------
## Features

- [x] Bug fix on clearStore

# shinyStorePlus 0.6
----------------------------------------------------------------------------
## Features

- [x] Store inputs automatically 
- [x] Retrieve all stored inputs
- [x] Clear Storage of all inputs
- [x] An example of the package in action
